==> haskell-wl-pprint-text-1.2.0.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-text
version:              1.2.0.2
visibility:           public
id:                   wl-pprint-text-1.2.0.2-261ct6hjWojFDMp9jlsvZu
key:                  wl-pprint-text-1.2.0.2-261ct6hjWojFDMp9jlsvZu
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  52d4c398dc757926fcc69a8361b23852
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-text
hs-libraries:         HSwl-pprint-text-1.2.0.2-261ct6hjWojFDMp9jlsvZu
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.2.0.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-text
version:              1.2.0.2
visibility:           public
id:                   wl-pprint-text-1.2.0.2-12iacaTETP2IDTZA1gWw7U
key:                  wl-pprint-text-1.2.0.2-12iacaTETP2IDTZA1gWw7U
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  e51f3d3da9aafdf7322f3ede566d43ad
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-text-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-text
hs-libraries:         HSwl-pprint-text-1.2.0.2-12iacaTETP2IDTZA1gWw7U
depends:
    base-4.17.2.1 base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
